read C:\Codes\rag-kmk\.github\prompts\refactor.prompt.md   prompt file. I already applied these refactoring in the codebase . I want you to run all the tests in C:\Codes\rag-kmk\tests and fix "test files only" if any errors. do not update or change the codebase files! some tests could become obselete, useless or unnecessary because of code refactoring. remove these tests as well. use conda activate rag env to run the test suit. I do not need and backward-compatible remove all the backward-compatible things. just update the tests files wrt exisiting codebase C:\Codes\rag-kmk\rag_kmk !!!! no body is using rag-kmk lib yet. Before starting read C:\Codes\rag-kmk\.github\instructions\copilot-instructions.md 